% Kernel learning via semi-infinite linear programming (SILP) in multi-class case
% Coded by Jianhui Chen (jianhui.chen@asu.edu, Arizona State University)

%                Input Parameters
% "G" : the cell containing centered kernel matrix (trace value = 1) 
% "H" : the indicator matrix
% "lambda" : regularization parameter
% "epislon" : tolerance parameter


%               Output parameters
% "theta" : the coefficients of kernel matrices
% "time" : computation time in seconds

function [ theta time ]  = SILP_multi( G, H, lambda, epislon );

time0 = cputime;

[ n, K ] = size( H );
len = length(G);

zeta = 10^300 ; 
theta = ones(1, len) / len;

f = [ ]; A = [ ]; b = [ ] ; B = [ ]; c = [ ]; l = [ ] ; u = [ ];
[ f A b B c l u ] = lp_con( len );

% alpha_set = [ ];

for t = 1 : 1000
    
    %t0 = cputime;
    [ alpha val ] = compute_alpha_ls(G, theta,lambda,H);
    %t1 = cputime; silp_time = t1- t0
        
    if (val > zeta) | ( abs(1-val/zeta) < epislon )
        break;
    else 
      %  ind = length(alpha_set)+1;
       % alpha_set{ind} = alpha; 
        
        %t0 = cputime;
        [ theta, zeta, f, A, b, B, c, l, u ] = compute_theta_lpprog( G, alpha, lambda, H, f, A, b, B, c, l, u );
        %t1 = cputime;  time_lpprog(t) = t1- t0
    end
    
    %   t0 = cputime;
    %   [ theta2, zeta2 ] = compute_theta_general( G, alpha_set, lambda, H );
    %   t1 = cputime;   time_mosek(t) = t1- t0
   
end


time = cputime - time0;